<?php
/**
 * @package		Joomla.Site
 * @subpackage	com_smsverify
 * @copyright	Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

require_once JPATH_COMPONENT.'/controller.php';
require_once JPATH_COMPONENT.'/api_send_sms.php';

/**
 * Registration controller class for Users.
 *
 * @package		Joomla.Site
 * @subpackage	com_smsverify
 * @since		1.6
 */
class SmsverifyControllerRegistration extends SmsverifyController
{
	/**
	 * Method to activate a user.
	 *
	 * @return	boolean		True on success, false on failure.
	 * @since	1.6
	 */
	
	public function activate()
	{
		$user		= JFactory::getUser();
		$uParams	= JComponentHelper::getParams('com_smsverify');

		// If the user is logged in, return them back to the homepage.
		if ($user->get('id')) {
			$this->setRedirect('index.php');
			return true;
		}

		// If user registration or account activation is disabled, throw a 403.
		if ($uParams->get('useractivation') == 0 || $uParams->get('allowUserRegistration') == 0) {
			JError::raiseError(403, JText::_('JLIB_APPLICATION_ERROR_ACCESS_FORBIDDEN'));
			return false;
		}

		$model = $this->getModel('Registration', 'UsersModel');
		$token = JRequest::getVar('token', null, 'request', 'alnum');

		// Check that the token is in a valid format.
		if ($token === null || strlen($token) !== 32) {
			JError::raiseError(403, JText::_('JINVALID_TOKEN'));
			return false;
		}

		// Attempt to activate the user.
		$return = $model->activate($token);

		// Check for errors.
		if ($return === false) {
			// Redirect back to the homepage.
			$this->setMessage(JText::sprintf('COM_SMSVERIFY_REGISTRATION_SAVE_FAILED', $model->getError()), 'warning');
			$this->setRedirect('index.php');
			return false;
		}

		$useractivation = $uParams->get('useractivation');

		// Redirect to the login screen.
		if ($useractivation == 0)
		{
			$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_SAVE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=login', false));
		}
		elseif ($useractivation == 1)
		{
			$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_ACTIVATE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));
		}
		elseif ($return->getParam('activate'))
		{
			$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_VERIFY_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify&layout=complete', false));
		}
		else
		{
			$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_ADMINACTIVATE_SUCCESS'));
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify', false));
		}
		return true;
	}

	/**
	 * Method to register a user.
	 *
	 * @return	boolean		True on success, false on failure.
	 * @since	1.6
	 */
	public function smsverify()
	{
		
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$app	= JFactory::getApplication();
		$model	= $this->getModel('Registration', 'SmsverifyModel');
		
		// Get the user data.
		$requestData = JRequest::getVar('jform', array(), 'post', 'array');

		// Validate the posted data.
		$form	= $model->getForm();
		if (!$form) {
			JError::raiseError(500, $model->getError());
			return false;
		}
		$data	= $model->validate($form, $requestData);
		
		// Check for validation errors.
		if ($data === false) {
			// Get the validation messages.
			$errors	= $model->getErrors();

			// Push up to three validation messages out to the user.
			for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
				if ($errors[$i] instanceof Exception) {
					$app->enqueueMessage($errors[$i]->getMessage(), 'warning');
				} else {
					$app->enqueueMessage($errors[$i], 'warning');
				}
			}

			// Save the data in the session.
			$app->setUserState('com_smsverify.registration.data', $requestData);

			// Redirect back to the registration screen.
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify', false));
			return false;
		}else{
			$uParams	= JComponentHelper::getParams('com_smsverify');
			$smslength=$uParams->get('smslength');
			$username=$uParams->get('username');
			$passwrd=$uParams->get('passwrd');
            
			$getnumber=$uParams->get('getnumber');
			$characters = array("0","1","2","3","4","5","6","7","8","9");
			$keys = array();
			while(count($keys) < $smslength) {
				$x = mt_rand(0, count($characters)-1);
				if(!in_array($x, $keys)) {
				   $keys[] = $x;
				}
			}
			foreach($keys as $key){
			   $randomNo .= $characters[$key];
			}
			// Save the data in the session.
			$requestData['password'] = $requestData['password2'];
			$requestData['vcode'] = $randomNo;
			$app->setUserState('com_smsverify.registration.data', $requestData);

            
            //majid sms send:D
            //
             //
            
            
   			if (($result = Send_SMS($username, $passwrd, $getnumber, $requestData['mobileno'], $randomNo, 0, false)) !== '0'){
				$app->enqueueMessage("Message Sending Fail. Please try again", 'warning');
		       	$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify', false));
			}  
            
            //majid 
			// Redirect back to the registration screen.
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=codeverification', false));
			return false;			
		}
		// Attempt to save the data.
		//$return	= $model->register($data);
		return true;
	}
	function verify(){
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		// Initialise variables.
		$app	= JFactory::getApplication();
		$model	= $this->getModel('Registration', 'SmsverifyModel');
		
		// Get the user data.
		$vData = JRequest::getVar('jform', array(), 'post', 'array');
			
		if($vData['vcode']==$vData['verificationcode']){
			// Attempt to save the data.
			$return	= $model->register($data);
			// Check for errors.
			if ($return === false) {
				// Save the data in the session.
				$app->setUserState('com_smsverify.registration.data', $data);
	
				// Redirect back to the edit screen.
				$this->setMessage(JText::sprintf('COM_SMSVERIFY_REGISTRATION_SAVE_FAILED', $model->getError()), 'warning');
				$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=registration', false));
				return false;
			}
			// Flush the data from the session.
			$app->setUserState('com_smsverify.registration.data', null);
			// Redirect to the profile screen.
			if ($return === 'adminactivate'){
				$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_COMPLETE_VERIFY'));
				$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify', false));
			} elseif ($return === 'useractivate') {
				$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_COMPLETE_ACTIVATE'));
				$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify', false));
			} else {
				$this->setMessage(JText::_('COM_SMSVERIFY_REGISTRATION_SAVE_SUCCESS'));
				$this->setRedirect(JRoute::_('index.php?option=com_users&view=login', false));
			}
			return true;
		}else if($vData['sendanother']){
			$requestData = JRequest::getVar('jform', array(), 'post', 'array');	
			$uParams	= JComponentHelper::getParams('com_smsverify');
			$smslength=$uParams->get('smslength');
			$username=$uParams->get('username');
			$passwrd=$uParams->get('passwrd');
		      $getnumber=$uParams->get('getnumber');
              
			$characters = array("0","1","2","3","4","5","6","7","8","9");
			$keys = array();
			while(count($keys) < $smslength) {
				$x = mt_rand(0, count($characters)-1);
				if(!in_array($x, $keys)) {
				   $keys[] = $x;
				}
			}
			foreach($keys as $key){
			   $randomNo .= $characters[$key];
			}
			// Save the data in the session.
			$requestData['vcode'] = $randomNo;
			$app->setUserState('com_smsverify.registration.data', $requestData);

			
            
            //majid sms
            	if (($result = Send_SMS($username, $passwrd, $getnumber, $requestData['mobileno'], $randomNo, 0, false)) !== '0'){
				$app->enqueueMessage("Message Sending Fail. Please try again", 'warning');
		       	$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=smsverify', false));
			}
     
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=codeverification', false));
			return false;
		}else{
			$app->enqueueMessage("Wrong Verification Code", 'warning');
			$this->setRedirect(JRoute::_('index.php?option=com_smsverify&view=codeverification', false));
			return false;
		}
	}
}
